==> lifetype-1.1.tbz: www/lifetype/plugins/atom/pluginatom.class.php <==
<?php

	include_once( PLOG_CLASS_PATH."class/plugin/pluginbase.class.php" );
	
	/**
	 * plugin registration and stuff like that...
	 */
	class PluginAtom extends PluginBase
	{

		function PluginAtom()
		{
			$this->PluginBase();

			$this->id = "atom";
			$this->desc = "Provides Atom access to your blog.";
			$this->author = "The LifeType Project";
			$this->locales = Array( "en_UK" );

			$this->init();
		}

		/**
		 * set some actions and menu options
		 * @private
		 */
		function init()
		{
			// register actions
			$this->registerAdminAction( "atomSettings", "AdminAtomPluginSettingsAction" );
			$this->registerAdminAction( "updateAtomSettings", "AdminAtomPluginUpdateSettingsAction" );

			// register menu entries
			$this->addMenuEntry( "/menu/controlCenter/manageSettings",   // menu path
                                             "atomSettings",    // menu id
                                             "admin.php?op=atomSettings",     // url
                                             "Atom",    // text to show
                                             true,       // can't...
                                             false       // ...remember :)
                                            );
		}



            /**
             * This method is only called when the list of plugins is being refreshed, so it's
             * a good time to create our tables
             */
		function install()
		{
			include_once( PLOG_CLASS_PATH."plugins/atom/class/dao/atompasswords.class.php" );
			$passwords = new AtomPasswords();
			$passwords->checkTables();

			return( true );
		}

	}
?>

==> lifetype-1.2.11.tbz: www/lifetype/plugins/atom/pluginatom.class.php <==
<?php

	lt_include( PLOG_CLASS_PATH."class/plugin/pluginbase.class.php" );
	
	/**
	 * plugin registration and stuff like that...
	 */
	class PluginAtom extends PluginBase
	{

		function PluginAtom( $source = "" )
		{
			$this->PluginBase( $source );

			$this->id = "atom";
			$this->desc = "Provides Atom access to your blog.";
			$this->author = "The LifeType Project";
			$this->locales = Array( "en_UK" );
            $this->version = "20070226";

            if( $source == "admin" );
			      $this->init();
		}

		/**
		 * set some actions and menu options
		 * @private
		 */
		function init()
		{
			// register actions
			$this->registerAdminAction( "atomSettings", "AdminAtomPluginSettingsAction" );
			$this->registerAdminAction( "updateAtomSettings", "AdminAtomPluginUpdateSettingsAction" );

			// register menu entries
			$this->addMenuEntry( "/menu/controlCenter/manageSettings",   // menu path
                                             "atomSettings",    // menu id
                                             "admin.php?op=atomSettings",     // url
                                             "Atom"    // text to show
                               );
		}



            /**
             * This method is only called when the list of plugins is being refreshed, so it's
             * a good time to create our tables
             */
		function install()
		{
			lt_include( PLOG_CLASS_PATH."plugins/atom/class/dao/atompasswords.class.php" );
			$passwords = new AtomPasswords();
			$passwords->checkTables();

			return( true );
		}

	}
?>
